/// <reference types="node" />
import { EventEmitter } from 'events';
import { lua_State } from 'fengari/src/lstate';
import War3Map from '../../parsers/w3x/map';
import JassPlayer from './types/player';
import Thread from './thread';
import JassHandle from './types/handle';
import JassLocation from './types/location';
import JassTimer from './types/timer';
import { JassTrigger } from './types/index';
/**
 * A Jass2 context.
 */
export default class Context extends EventEmitter {
    L: lua_State;
    map: War3Map | null;
    handle: number;
    freeHandles: number[];
    handles: (JassHandle | null)[];
    name: string;
    description: string;
    players: JassPlayer[];
    actualPlayers: number;
    startLocations: JassLocation[];
    constantHandles: {
        playerColors: import("./types/playercolor").default[];
        races: import("./types/race").default[];
        playerGameResults: import("./types/playergameresult").default[];
        allianceTypes: import("./types/alliancetype").default[];
        versions: import("./types/version").default[];
        attackTypes: import("./types/attacktype").default[];
        damageTypes: import("./types/damagetype").default[];
        weaponTypes: import("./types/weapontype").default[];
        pathingTypes: import("./types/pathingtype").default[];
        mouseButtonTypes: import("./types/mousebuttontype").default[];
        animTypes: import("./types/animtype").default[];
        subAnimTypes: import("./types/subanimtype").default[];
        racePrefs: import("./types/racepreference").default[];
        mapControls: import("./types/mapcontrol").default[];
        gameTypes: import("./types/gametype").default[];
        mapFlags: import("./types/mapflag").default[];
        placements: import("./types/placement").default[];
        startLocPrios: import("./types/startlocprio").default[];
        mapDensities: import("./types/mapdensity").default[];
        gameDifficulties: import("./types/gamedifficulty").default[];
        gameSpeeds: import("./types/gamespeed").default[];
        playerSlotStates: import("./types/playerslotstate").default[];
        volumeGroups: import("./types/volumegroup").default[];
        gameStates: (import("./types/igamestate").default | import("./types/fgamestate").default)[];
        playerStates: import("./types/playerstate").default[];
        unitStates: import("./types/unitstate").default[];
        aiDifficulties: import("./types/aidifficulty").default[];
        playerScores: import("./types/playerscore").default[];
        events: (import("./types/gameevent").default | import("./types/playerevent").default | import("./types/playerunitevent").default | import("./types/unitevent").default | import("./types/widgetevent").default | import("./types/dialogevent").default)[];
        limitOps: import("./types/limitop").default[];
        unitTypes: import("./types/unittype").default[];
        itemTypes: import("./types/itemtype").default[];
        cameraFields: import("./types/camerafield").default[];
        blendModes: import("./types/blendmode").default[];
        rarityControls: import("./types/raritycontrol").default[];
        texMapFlags: import("./types/texmapflags").default[];
        fogStates: import("./types/fogstate").default[];
        effectTypes: import("./types/effecttype").default[];
        soundTypes: import("./types/soundtype").default[];
    };
    timers: Set<JassTimer>;
    triggers: Set<JassTrigger>;
    threads: Set<Thread>;
    currentThread: Thread | null;
    enumUnit: JassHandle | null;
    filterUnit: JassHandle | null;
    enumPlayer: JassHandle | null;
    t: number;
    constructor();
    start(): void;
    step(): void;
    addHandle(handle: JassHandle): JassHandle;
    freeHandle(handle: JassHandle): void;
    call(name?: string | number): void;
    run(code: string, isJass: boolean): void;
    open(map: War3Map): void;
}
